==> veyon_4.1.7+repack1.orig.tar.xz: veyon-4.1.7/core/include/NetworkObjectDirectoryPluginInterface.h <==
/*
 * NetworkObjectDirectoryPluginInterface.h - plugin interface for network
 *                                           object directory implementations
 *
 * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
 *
 * This file is part of Veyon - http://veyon.io
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program (see COPYING); if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 */

#ifndef NETWORK_OBJECT_DIRECTORY_PLUGIN_INTERFACE_H
#define NETWORK_OBJECT_DIRECTORY_PLUGIN_INTERFACE_H

#include "PluginInterface.h"

class NetworkObjectDirectory;

// clazy:excludeall=copyable-polymorphic

class NetworkObjectDirectoryPluginInterface
{
public:
	virtual QString directoryName() const = 0;
	virtual NetworkObjectDirectory* createNetworkObjectDirectory( QObject* parent ) = 0;

};

typedef QList<NetworkObjectDirectoryPluginInterface> NetworkObjectDirectoryPluginInterfaceList;

#define NetworkObjectDirectoryPluginInterface_iid "io.veyon.Veyon.Plugins.NetworkObjectPluginInterface"

Q_DECLARE_INTERFACE(NetworkObjectDirectoryPluginInterface, NetworkObjectDirectoryPluginInterface_iid)

#endif // NETWORK_OBJECT_DIRECTORY_PLUGIN_INTERFACE_H

==> veyon_4.3.1+repack1.orig.tar.xz: veyon-4.3.1/core/include/NetworkObjectDirectoryPluginInterface.h <==
/*
 * NetworkObjectDirectoryPluginInterface.h - plugin interface for network
 *                                           object directory implementations
 *
 * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
 *
 * This file is part of Veyon - https://veyon.io
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program (see COPYING); if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 */

#pragma once

#include "PluginInterface.h"

class NetworkObjectDirectory;

// clazy:excludeall=copyable-polymorphic

class NetworkObjectDirectoryPluginInterface
{
public:
	virtual QString directoryName() const = 0;
	virtual NetworkObjectDirectory* createNetworkObjectDirectory( QObject* parent ) = 0;

};

using NetworkObjectDirectoryPluginInterfaceList = QList<NetworkObjectDirectoryPluginInterface>;

#define NetworkObjectDirectoryPluginInterface_iid "io.veyon.Veyon.Plugins.NetworkObjectPluginInterface"

Q_DECLARE_INTERFACE(NetworkObjectDirectoryPluginInterface, NetworkObjectDirectoryPluginInterface_iid)
